@@ -1,7 +1,7 @@
 use Win32::PerfMon;
 use strict;
 
-my $ServerName = "<Server Name Goes Here>";
+my $ServerName = "<server name goes here>";
 my $ret = undef;
 my $err = undef;
 
@@ -10,15 +10,15 @@ my $xxx = Win32::PerfMon->new("\\\\$ServerName");
 if($xxx != undef)
 {
 	$ret = $xxx->AddCounter("System", "System Up Time", -1);
-	
+
 	if($ret != 0)
 	{
 		$ret = $xxx->CollectData();
-		
+
 		if($ret  != 0)
 		{
 			my $secs = $xxx->GetCounterValue("System", "System Up Time", -1);
-			
+
 			if($secs > -1)
 			{
 				print "Seconds of Up Time = [$secs]\n";
@@ -26,23 +26,24 @@ if($xxx != undef)
 			else
 			{
 				$err = $xxx->GetErrorText();
-				
+
 				print "Failed to get the counter data ", $err, "\n";
 			}
 		}
 		else
 		{
 			$err = $xxx->GetErrorText();
-							
+
 			print "Failed to collect the perf data ", $err, "\n";
 		}
 	}
 	else
 	{
 		$err = $xxx->GetErrorText();
-						
+
 		print "Failed to add the counter ", $err, "\n";
 	}
+    
 }
 else
 {				
